@@ -1,8 +1,13 @@
 import httpx
 
 from statuscheck.services.bases._base import BaseServiceAPI
-from statuscheck.services.models import signal
-from statuscheck.services.models.generic import Status, Summary
+from statuscheck.services.models.generic import TYPE_GOOD, Status, Summary
+
+STATUS_OK = "Signal is up and running."
+
+STATUS_TYPE_MAPPING = {
+    STATUS_OK: TYPE_GOOD,
+}
 
 
 class ServiceAPI(BaseServiceAPI):
@@ -17,11 +22,11 @@ class ServiceAPI(BaseServiceAPI):
         response = httpx.get(self.base_url)
         response.raise_for_status()
         text = response.text
-        if signal.STATUS_OK in text:
+        if STATUS_OK in text:
             status = Status(
-                code=signal.STATUS_OK,
-                name=signal.STATUS_TYPE_MAPPING[signal.STATUS_OK],
-                description=signal.STATUS_TYPE_MAPPING[signal.STATUS_OK],
+                code=STATUS_OK,
+                name=STATUS_TYPE_MAPPING[STATUS_OK],
+                description=STATUS_TYPE_MAPPING[STATUS_OK],
                 is_ok=True,
             )
             return Summary(status=status, components=[], incidents=[])
