@@ -1,6 +1,7 @@
 import respx
+from httpx import Response
 
-from statuscheck.services.models.statuspageio import STATUS_MAINTENANCE
+from statuscheck.services.bases._statuspageio import STATUS_MAINTENANCE
 from statuscheck.utils import get_statuscheck_api
 
 
@@ -13,9 +14,7 @@ class TestCloudAMQP:
             mock_response_body = f.read()
         respx.get(
             "https://2126xm8ctzlk.statuspage.io/api/v2/summary.json",
-            status_code=200,
-            content=mock_response_body,
-        )
+        ).mock(return_value=Response(200, content=mock_response_body))
 
         service_name = "cloudamqp"
         service_api = get_statuscheck_api(service_name)
